Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(287)

Unified Diff: media/audio/mac/audio_manager_mac.h

Issue 233823003: Defer input stream start around suspend and resume. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fix tests. Created 6 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « media/audio/mac/audio_low_latency_input_mac_unittest.cc ('k') | media/audio/mac/audio_manager_mac.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/audio/mac/audio_manager_mac.h
diff --git a/media/audio/mac/audio_manager_mac.h b/media/audio/mac/audio_manager_mac.h
index 7cc1a63fc297ec644d40602a6f1e28ead5a5c02d..490b0b6bbdddecaf20c69f6ad5088d41ff3664ab 100644
--- a/media/audio/mac/audio_manager_mac.h
+++ b/media/audio/mac/audio_manager_mac.h
@@ -69,11 +69,11 @@ class MEDIA_EXPORT AudioManagerMac : public AudioManagerBase {
// As a workaround we delay Start() when it occurs after suspend and for a
// small amount of time after resume.
//
// Output streams should consult ShouldDeferOutputStreamStart() and if true
// check the value again after |kStartDelayInSecsForPowerEvents| has elapsed.
// If false, the stream may be started immediately.
enum { kStartDelayInSecsForPowerEvents = 1 };
- bool ShouldDeferOutputStreamStart();
+ bool ShouldDeferStreamStart();
protected:
virtual ~AudioManagerMac();
« no previous file with comments | « media/audio/mac/audio_low_latency_input_mac_unittest.cc ('k') | media/audio/mac/audio_manager_mac.cc » ('j') | no next file with comments »
@@ -69,11 +69,11 @@ class MEDIA_EXPORT AudioManagerMac : public AudioManagerBase {
// small amount of time after resume.
//
- // Output streams should consult ShouldDeferOutputStreamStart() and if true
- // check the value again after |kStartDelayInSecsForPowerEvents| has elapsed.
- // If false, the stream may be started immediately.
+ // Streams should consult ShouldDeferStreamStart() and if true check the value
+ // again after |kStartDelayInSecsForPowerEvents| has elapsed. If false, the
+ // stream may be started immediately.
enum { kStartDelayInSecsForPowerEvents = 1 };

Powered by Google App Engine
This is Rietveld 408576698